:orphan:



.. _sphx_glr_documentation_auto_examples:

================================================
scikit-learn examples adapted for scikit-hubness
================================================

Examples concerning using :mod:`skhubness.neighbors`
as drop-in replacement for :mod:`sklearn.neighbors`.

These examples are taken from scikit-learn and demonstrate the ease of transition
from ``sklearn.neighbors`` to ``skhubness.neighbors``.
You will find that many examples require no more than modifying an import line,
and/or adding one argument when instantiating an estimator.

Note, that these examples are not intended to demonstrate improved learning performance
due to hubness reduction (the data are rather low-dimensional).



.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="Demonstrate the resolution of a regression problem using a k-Nearest Neighbor and the interpola...">

.. only:: html

    .. figure:: /documentation/auto_examples/images/thumb/sphx_glr_plot_regression_thumb.png

        :ref:`sphx_glr_documentation_auto_examples_plot_regression.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /documentation/auto_examples/plot_regression

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="Sample usage of Nearest Centroid classification. It will plot the decision boundaries for each ...">

.. only:: html

    .. figure:: /documentation/auto_examples/images/thumb/sphx_glr_plot_nearest_centroid_thumb.png

        :ref:`sphx_glr_documentation_auto_examples_plot_nearest_centroid.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /documentation/auto_examples/plot_nearest_centroid

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="Adapted from `&lt;https://scikit-learn.org/stable/auto_examples/neighbors/plot_classification.html...">

.. only:: html

    .. figure:: /documentation/auto_examples/images/thumb/sphx_glr_plot_classification_thumb.png

        :ref:`sphx_glr_documentation_auto_examples_plot_classification.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /documentation/auto_examples/plot_classification

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="Sample usage of Neighborhood Components Analysis for dimensionality reduction.">

.. only:: html

    .. figure:: /documentation/auto_examples/images/thumb/sphx_glr_plot_nca_dim_reduction_thumb.png

        :ref:`sphx_glr_documentation_auto_examples_plot_nca_dim_reduction.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /documentation/auto_examples/plot_nca_dim_reduction

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="This example shows the use of multi-output estimator to complete images. The goal is to predict...">

.. only:: html

    .. figure:: /documentation/auto_examples/images/thumb/sphx_glr_plot_multioutput_face_completion_thumb.png

        :ref:`sphx_glr_documentation_auto_examples_plot_multioutput_face_completion.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /documentation/auto_examples/plot_multioutput_face_completion

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="An example comparing nearest neighbors classification with and without Neighborhood Components ...">

.. only:: html

    .. figure:: /documentation/auto_examples/images/thumb/sphx_glr_plot_nca_classification_thumb.png

        :ref:`sphx_glr_documentation_auto_examples_plot_nca_classification.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /documentation/auto_examples/plot_nca_classification

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="An illustration of various embeddings on the digits dataset.">

.. only:: html

    .. figure:: /documentation/auto_examples/images/thumb/sphx_glr_plot_lle_digits_thumb.png

        :ref:`sphx_glr_documentation_auto_examples_plot_lle_digits.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /documentation/auto_examples/plot_lle_digits
.. raw:: html

    <div style='clear:both'></div>



.. only :: html

 .. container:: sphx-glr-footer
    :class: sphx-glr-footer-gallery


  .. container:: sphx-glr-download

    :download:`Download all examples in Python source code: auto_examples_python.zip <//home/user/feldbauer/PycharmProjects/hubness/docs/documentation/auto_examples/auto_examples_python.zip>`



  .. container:: sphx-glr-download

    :download:`Download all examples in Jupyter notebooks: auto_examples_jupyter.zip <//home/user/feldbauer/PycharmProjects/hubness/docs/documentation/auto_examples/auto_examples_jupyter.zip>`


.. only:: html

 .. rst-class:: sphx-glr-signature

    `Gallery generated by Sphinx-Gallery <https://sphinx-gallery.github.io>`_
